@@ -295,6 +295,12 @@
 (defprop mbox wxxml-mbox wxxml)
 (defprop mlabox wxxml-mbox wxxml)
 
+(defprop mbox 10. wxxml-rbp)
+(defprop mbox 10. wxxml-lbp)
+
+(defprop mlabbox 10. wxxml-rbp)
+(defprop mlabbox 10. wxxml-lbp)
+
 (defun wxxml-mbox (x l r)
   (setq l (wxxml (cadr x) (append l '("<hl>")) nil 'mparen 'mparen)
         r (append '("</hl>") r))
@@ -1559,7 +1565,8 @@
 	(args (mapcar (lambda (u)
 			(cond ((atom u) (symbol-to-string u))
 			      ((eq (caar u) 'mlist)
-			       ($concat "[" (symbol-to-string (cadr u)) "]"))
+			       ($concat "[" (symbol-to-string
+                                             (if (atom (cadr u)) (cadr u) (cadadr u))) "]"))
 			      (t (symbol-to-string (cadr u)))))
 		      (cdr fun))))
     (format nil "FUNCTION: ~a$TEMPLATE: ~a(~{<~a>~^, ~})" fun-name fun-name args)))
