@@ -136,7 +136,7 @@ void Config::SetProperties()
   wxString mp, mc, ib, mf;
   bool match = true, showLongExpr = false, savePanes = false;
   bool fixedFontTC = true, changeAsterisk = false, usejsmath = true, keepPercent = true;
-  bool enterEvaluates = false, saveUntitled = true;
+  bool enterEvaluates = false, saveUntitled = true, openHCaret = false;
   int rs = 0;
   int lang = wxLANGUAGE_UNKNOWN;
   int panelSize = 1;
@@ -153,6 +153,7 @@ void Config::SetProperties()
   config->Read(wxT("panelSize"), &panelSize);
   config->Read(wxT("enterEvaluates"), &enterEvaluates);
   config->Read(wxT("saveUntitled"), &saveUntitled);
+  config->Read(wxT("openHCaret"), &openHCaret);
   config->Read(wxT("usejsmath"), &usejsmath);
   config->Read(wxT("keepPercent"), &keepPercent);
 
@@ -204,6 +205,7 @@ void Config::SetProperties()
   m_changeAsterisk->SetValue(changeAsterisk);
   m_enterEvaluates->SetValue(enterEvaluates);
   m_saveUntitled->SetValue(saveUntitled);
+  m_openHCaret->SetValue(openHCaret);
   m_fixedFontInTC->SetValue(fixedFontTC);
   m_useJSMath->SetValue(usejsmath);
   m_keepPercentWithSpecials->SetValue(keepPercent);
@@ -225,7 +227,7 @@ wxPanel* Config::CreateOptionsPanel()
   wxPanel *panel = new wxPanel(m_notebook, -1);
 
   wxFlexGridSizer* grid_sizer = new wxFlexGridSizer(2, 2, 5, 5);
-  wxFlexGridSizer* vsizer = new wxFlexGridSizer(10,1,5,5);
+  wxFlexGridSizer* vsizer = new wxFlexGridSizer(11,1,5,5);
 
   int defaultPort = 4010;
   wxConfig::Get()->Read(wxT("defaultPort"), &defaultPort);
@@ -264,6 +266,7 @@ wxPanel* Config::CreateOptionsPanel()
   m_keepPercentWithSpecials = new wxCheckBox(panel, -1, _("Keep percent sign with special symbols: %e, %i, etc."));
   m_enterEvaluates = new wxCheckBox(panel, -1, _("Enter evaluates cells"));
   m_saveUntitled = new wxCheckBox(panel, -1, _("Ask to save untitled documents"));
+  m_openHCaret = new wxCheckBox(panel, -1, _("Open a cell when Maxima expects input"));
 
   // TAB 1
   // Maxima options box
@@ -283,8 +286,9 @@ wxPanel* Config::CreateOptionsPanel()
   vsizer->Add(m_keepPercentWithSpecials, 0, wxALL, 5);
   vsizer->Add(m_enterEvaluates, 0, wxALL, 5);
   vsizer->Add(m_saveUntitled, 0, wxALL, 5);
+  vsizer->Add(m_openHCaret, 0, wxALL, 5);
 
-  vsizer->AddGrowableRow(9);
+  vsizer->AddGrowableRow(10);
   panel->SetSizer(vsizer);
   vsizer->Fit(panel);
 
@@ -442,6 +446,7 @@ void Config::WriteSettings()
   config->Write(wxT("changeAsterisk"), m_changeAsterisk->GetValue());
   config->Write(wxT("enterEvaluates"), m_enterEvaluates->GetValue());
   config->Write(wxT("saveUntitled"), m_saveUntitled->GetValue());
+  config->Write(wxT("openHCaret"), m_openHCaret->GetValue());
   config->Write(wxT("defaultPort"), m_defaultPort->GetValue());
   config->Write(wxT("AUI/savePanes"), m_savePanes->GetValue());
   config->Write(wxT("usejsmath"), m_useJSMath->GetValue());
@@ -490,7 +495,8 @@ void Config::OnMpBrowse(wxCommandEvent& event)
 void Config::OnMathBrowse(wxCommandEvent& event)
 {
   wxFont math;
-  math = wxGetFontFromUser(this, wxFont(m_mathFontSize, wxNORMAL, wxNORMAL, wxNORMAL,
+  math = wxGetFontFromUser(this, wxFont(m_mathFontSize, wxFONTFAMILY_DEFAULT,
+                                        wxFONTSTYLE_NORMAL, wxFONTWEIGHT_NORMAL,
                                         false, m_mathFontName));
 
   if (math.Ok())
@@ -519,7 +525,8 @@ void Config::OnChangeFontFamily(wxCommandEvent& event)
     fontName = m_styleDefault.font;
 
   font = wxGetFontFromUser(this, wxFont(fontsize,
-                                        wxNORMAL, wxNORMAL, wxNORMAL,
+                                        wxFONTFAMILY_DEFAULT, wxFONTSTYLE_NORMAL,
+                                        wxFONTWEIGHT_NORMAL,
                                         false, fontName,
                                         m_fontEncoding));
   if (font.Ok())
@@ -1106,7 +1113,7 @@ void ExamplePanel::OnPaint(wxPaintEvent& event)
   wxPaintDC dc(this);
   int panel_width, panel_height;
   int text_width, text_height;
-  int bold = wxNORMAL, italic = wxNORMAL, underlined = 0;
+  int bold = wxFONTWEIGHT_NORMAL, italic = wxFONTSTYLE_NORMAL, underlined = 0;
 
   GetClientSize(&panel_width, &panel_height);
 
@@ -1118,7 +1125,7 @@ void ExamplePanel::OnPaint(wxPaintEvent& event)
     italic = wxSLANT;
   if (m_underlined)
     underlined = 1;
-  dc.SetFont(wxFont(m_size, wxMODERN, italic, bold, underlined, m_font));
+  dc.SetFont(wxFont(m_size, wxFONTFAMILY_MODERN, italic, bold, underlined, m_font));
   dc.GetTextExtent(example, &text_width, &text_height);
 
   dc.DrawText(example, (panel_width - text_width) / 2,
