@@ -223,6 +223,9 @@ void wxMaximaFrame::SetupMenu()
   wxglade_tmp_menu_2->Append(menu_undo, _("Undo\tCtrl-Z"),
                              _("Undo last change"),
                              wxITEM_NORMAL);
+  wxglade_tmp_menu_2->Append(menu_redo, _("Redo\tCtrl-Shift-Z"),
+                             _("Redo last change"),
+                             wxITEM_NORMAL);
   wxglade_tmp_menu_2->AppendSeparator();
   wxglade_tmp_menu_2->Append(menu_cut, _("Cut\tCtrl-X"),
                              _("Cut selection"),
@@ -273,8 +276,13 @@ void wxMaximaFrame::SetupMenu()
                              _("Toggle full screen editing"),
                              wxITEM_NORMAL);
   wxglade_tmp_menu_2->AppendSeparator();
+#if defined __WXMAC__
+  APPEND_MENU_ITEM(wxglade_tmp_menu_2, wxID_PREFERENCES, _("Preferences...\tCTRL+,"),
+                   _("Configure wxMaxima"), wxT("gtk-preferences"));
+#else
   APPEND_MENU_ITEM(wxglade_tmp_menu_2, wxID_PREFERENCES, _("C&onfigure"),
                    _("Configure wxMaxima"), wxT("gtk-preferences"));
+#endif
   frame_1_menubar->Append(wxglade_tmp_menu_2, _("&Edit"));
 
   // Cell menu
@@ -635,8 +643,13 @@ void wxMaximaFrame::SetupMenu()
 
   // Help menu
   wxMenu* wxglade_tmp_menu_7 = new wxMenu;
+#if defined __WXMAC__
+  wxglade_tmp_menu_7->Append(wxID_HELP, _("Maxima &Help\tCTRL+?"),
+                             _("Show Maxima help"), wxITEM_NORMAL);
+#else
   APPEND_MENU_ITEM(wxglade_tmp_menu_7, wxID_HELP, _("Maxima &Help\tF1"),
                    _("Show Maxima help"), wxT("gtk-help"));
+#endif
   wxglade_tmp_menu_7->Append(menu_example, _("&Example..."),
                              _("Show an example of usage"),
                              wxITEM_NORMAL);
