@@ -161,7 +161,7 @@ enum {
   menu_copy_tex_from_console,
   menu_copy_text_from_console,
   menu_undo,
-  menu_delete_selection,
+  menu_redo,
   menu_select_all,
   menu_logcontract,
   menu_logexpand,
